from setuptools import setup

setup(
    name='muispasswordgen',
    version='1.1.0',
    description='A password generation module',
    author='muis',
    author_email='exlkip@gmail.com',
    url='',
    py_modules=['muispasswordgen'],
    python_requires='>=3.6',
)
